@@ -8,12 +8,18 @@ use Business::UPS;
 #
 my ($shipping,$ups_zone,$error) = getUPS(qw/GNDCOM 23606 11111 50/);
 $error and die "ERROR: $error\n";
+print "UPS Version " . $Business::UPS::VERSION . "\n";
+print "From: 23606 to 11111 Weight 50 GNDCOM\n";
 print "Shipping is \$$shipping\n";
 print "UPS Zone is $ups_zone\n";
+exit(0);
 
 # How about a shipment from the US to Great Britain
 #
-my ($shipping,$ups_zone,$error) = getUPS('XPR', '23606', 'B67JH', '10', 'GB', '', '', '', '', '');
+my ($type,$from,$to,$wgt,$co) = qw/XPR 23606 B67JH 10 GB/;
+my ($shipping,$ups_zone,$error) = getUPS($type,$from,$to,$wgt,$co,'', '', '', '', '');
+print "Tying:\n";
+print "From: $from\nTo:$to\nWeight: $wgt\nCountry:	$co\n";
 $error and die "ERROR: $error\n";
 print "Shipping is \$$shipping\n";
 print "UPS Zone is $ups_zone\n";
